searchData={"items":[{"type":"module","title":"Cldr.LocaleDisplay","doc":"Implements the [CLDR locale display name algorithm](https://unicode-org.github.io/cldr/ldml/tr35-general.html#locale_display_name_algorithm) to format\na `t:Cldr.LanguageTag` structs for presentation uses.","ref":"Cldr.LocaleDisplay.html"},{"type":"function","title":"Cldr.LocaleDisplay.display_name/2","doc":"Returns a localised display name for a\nlocale.\n\nUI applications often have a requirement\nto present locale choices to an end user.\n\nThis function takes a `t.Cldr.LanguageTag`\nand using the [CLDR locale display name algorithm](https://unicode-org.github.io/cldr/ldml/tr35-general.html#locale_display_name_algorithm)\nproduces a string suitable for presentation.","ref":"Cldr.LocaleDisplay.html#display_name/2"},{"type":"function","title":"Arguments - Cldr.LocaleDisplay.display_name/2","doc":"* `language_tag` is any `t:Cldr.LanguageTag` or\n  a locale name as an atom or string.\n\n* `options` is a keyword list of options.","ref":"Cldr.LocaleDisplay.html#display_name/2-arguments"},{"type":"function","title":"Options - Cldr.LocaleDisplay.display_name/2","doc":"* `:compound_locale` is a boolean indicating\n  if the combination of language, script and territory\n  should be used to resolve a language name.\n  The default is `true`.\n\n* `:prefer` signals the preferred name for\n  a subtag when there are alternatives.\n  The default is `:default`. Few subtags\n  provide alternative renderings. Some of\n  the alternative preferences are`:short`,\n  `:long`, `:menu` and `:variant`.\n\n* `:locale` is a `t:Cldr.LanguageTag` or any valid\n  locale name returned by `Cldr.known_locale_names/1`.\n\n* `:backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.","ref":"Cldr.LocaleDisplay.html#display_name/2-options"},{"type":"function","title":"Returns - Cldr.LocaleDisplay.display_name/2","doc":"* `{:ok, string}` representing a name\n  suitable for presentation purposes or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.LocaleDisplay.html#display_name/2-returns"},{"type":"function","title":"Examples - Cldr.LocaleDisplay.display_name/2","doc":"iex> Cldr.LocaleDisplay.display_name \"en\"\n    {:ok, \"English\"}\n\n    iex> Cldr.LocaleDisplay.display_name \"en-US\"\n    {:ok, \"American English\"}\n\n    iex> Cldr.LocaleDisplay.display_name \"en-US\", compound_locale: false\n    {:ok, \"English (United States)\"}\n\n    iex> Cldr.LocaleDisplay.display_name \"en-US-u-ca-gregory-cu-aud\"\n    {:ok, \"American English (Gregorian Calendar, Currency: A$)\"}\n\n    iex> Cldr.LocaleDisplay.display_name \"en-US-u-ca-gregory-cu-aud\", locale: \"fr\"\n    {:ok, \"anglais américain (calendrier grégorien, devise : A$)\"}\n\n    iex> Cldr.LocaleDisplay.display_name \"nl-BE\"\n    {:ok, \"Flemish\"}\n\n    iex> Cldr.LocaleDisplay.display_name \"nl-BE\", compound_locale: false\n    {:ok, \"Dutch (Belgium)\"}","ref":"Cldr.LocaleDisplay.html#display_name/2-examples"},{"type":"function","title":"Cldr.LocaleDisplay.display_name!/2","doc":"Returns a localised display name for a\nlocale.\n\nUI applications often have a requirement\nto present locale choices to an end user.\n\nThis function takes a `t.Cldr.LanguageTag`\nand using the [CLDR locale display name algorithm](https://unicode-org.github.io/cldr/ldml/tr35-general.html#locale_display_name_algorithm)\nproduces a string suitable for presentation.","ref":"Cldr.LocaleDisplay.html#display_name!/2"},{"type":"function","title":"Arguments - Cldr.LocaleDisplay.display_name!/2","doc":"* `language_tag` is any `t:Cldr.LanguageTag` or\n  a locale name as an atom or string.\n\n* `options` is a keyword list of options.","ref":"Cldr.LocaleDisplay.html#display_name!/2-arguments"},{"type":"function","title":"Options - Cldr.LocaleDisplay.display_name!/2","doc":"* `:compound_locale` is a boolean indicating\n  if the combination of language, script and territory\n  should be used to resolve a language name.\n  The default is `true`.\n\n* `:prefer` signals the preferred name for\n  a subtag when there are alternatives.\n  The default is `:default`. Few subtags\n  provide alternative renderings. Some of\n  the alternative preferences are`:short`,\n  `:long`, `:menu` and `:variant`.\n\n* `:locale` is a `t:Cldr.LanguageTag` or any valid\n  locale name returned by `Cldr.known_locale_names/1`.\n\n* `:backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.","ref":"Cldr.LocaleDisplay.html#display_name!/2-options"},{"type":"function","title":"Returns - Cldr.LocaleDisplay.display_name!/2","doc":"* a string representation of the language tag\n  suitable for presentation purposes or\n\n* raises an exception.","ref":"Cldr.LocaleDisplay.html#display_name!/2-returns"},{"type":"function","title":"Examples - Cldr.LocaleDisplay.display_name!/2","doc":"iex> Cldr.LocaleDisplay.display_name! \"en\"\n    \"English\"\n\n    iex> Cldr.LocaleDisplay.display_name! \"en-US\"\n    \"American English\"\n\n    iex> Cldr.LocaleDisplay.display_name! \"en-US\", compound_locale: false\n    \"English (United States)\"\n\n    iex> Cldr.LocaleDisplay.display_name! \"en-US-u-ca-gregory-cu-aud\"\n    \"American English (Gregorian Calendar, Currency: A$)\"\n\n    iex> Cldr.LocaleDisplay.display_name! \"en-US-u-ca-gregory-cu-aud\", locale: \"fr\"\n    \"anglais américain (calendrier grégorien, devise : A$)\"","ref":"Cldr.LocaleDisplay.html#display_name!/2-examples"},{"type":"type","title":"Cldr.LocaleDisplay.display_options/0","doc":"","ref":"Cldr.LocaleDisplay.html#t:display_options/0"},{"type":"module","title":"Cldr.LocaleDisplay.Extension","doc":"","ref":"Cldr.LocaleDisplay.Extension.html"},{"type":"function","title":"Cldr.LocaleDisplay.Extension.display_name/2","doc":"","ref":"Cldr.LocaleDisplay.Extension.html#display_name/2"},{"type":"module","title":"Cldr.LocaleDisplay.PrivateUse","doc":"","ref":"Cldr.LocaleDisplay.PrivateUse.html"},{"type":"function","title":"Cldr.LocaleDisplay.PrivateUse.display_name/2","doc":"","ref":"Cldr.LocaleDisplay.PrivateUse.html#display_name/2"},{"type":"module","title":"Cldr.LocaleDisplay.T","doc":"","ref":"Cldr.LocaleDisplay.T.html"},{"type":"function","title":"Cldr.LocaleDisplay.T.display_name/2","doc":"","ref":"Cldr.LocaleDisplay.T.html#display_name/2"},{"type":"function","title":"Cldr.LocaleDisplay.T.format_key_value/6","doc":"","ref":"Cldr.LocaleDisplay.T.html#format_key_value/6"},{"type":"module","title":"Cldr.LocaleDisplay.U","doc":"","ref":"Cldr.LocaleDisplay.U.html"},{"type":"function","title":"Cldr.LocaleDisplay.U.display_name/2","doc":"","ref":"Cldr.LocaleDisplay.U.html#display_name/2"},{"type":"function","title":"Cldr.LocaleDisplay.U.format_key_value/6","doc":"","ref":"Cldr.LocaleDisplay.U.html#format_key_value/6"},{"type":"function","title":"Cldr.LocaleDisplay.U.get_currency/2","doc":"","ref":"Cldr.LocaleDisplay.U.html#get_currency/2"},{"type":"function","title":"Cldr.LocaleDisplay.U.get_timezone/2","doc":"","ref":"Cldr.LocaleDisplay.U.html#get_timezone/2"},{"type":"exception","title":"Cldr.DisplayName.NoDataError","doc":"Exception raised when resolving a locale display name\nand there is no data in the requested locale (typically :und).","ref":"Cldr.DisplayName.NoDataError.html"},{"type":"extras","title":"Cldr Locale Display","doc":"# Cldr Locale Display\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_cldr_locale_display.svg)](https://hex.pm/packages/ex_cldr_locale_display)\n[![Hex.pm](https://img.shields.io/hexpm/dw/ex_cldr_locale_display.svg?)](https://hex.pm/packages/ex_cldr_locale_display)\n[![Hex.pm](https://img.shields.io/hexpm/dt/ex_cldr_locale_display.svg?)](https://hex.pm/packages/ex_cldr_locale_display)\n[![Hex.pm](https://img.shields.io/hexpm/l/ex_cldr_locale_display.svg)](https://hex.pm/packages/ex_cldr_locale_display)\n\nPresents language tags in a presentation format suitable for UI applications.\nIt implements the [CLDR locale display name algorithm](https://unicode-org.github.io/cldr/ldml/tr35-general.html#locale_display_name_algorithm).","ref":"readme.html"},{"type":"extras","title":"Installation - Cldr Locale Display","doc":"The package can be installed by adding `ex_cldr_locale_display` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_cldr_locale_display, \"~> 1.1\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/ex_cldr_locale_display](https://hexdocs.pm/ex_cldr_locale_display).","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Cldr Locale Display","doc":"In keeping with all `ex_cldr`-based libraries, a backend module is required which hosts the display data used to produce locale display names. A simple example is given here. For full information on configuring a backend module, see the [configuration section](https://hexdocs.pm/ex_cldr/readme.html#configuration) for [ex_cldr](https://hex.pm/packages/ex_cldr).\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"de\", \"th\", \"fr\", \"fr-CH\", \"zh\", \"ar\"],\n    default_locale: \"en\",\n    providers: [Cldr.Territory, Cldr.LocaleDisplay, Cldr.Currency]\nend\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Examples - Cldr Locale Display","doc":"The follow examples require that a `:default_backend` be set in `config.exs` for the `:ex_cldr` configuration key. See the [configuration section](https://hexdocs.pm/ex_cldr/readme.html#configuration) for [ex_cldr](https://hex.pm/packages/ex_cldr) for more information.\n\n```elixir\niex> Cldr.LocaleDisplay.display_name \"en\"\n{:ok, \"English\"}\n\niex> Cldr.LocaleDisplay.display_name \"en-US\"\n{:ok, \"American English\"}\n\niex> Cldr.LocaleDisplay.display_name \"en-US\", compound_locale: false\n{:ok, \"English (United States)\"}\n\niex> Cldr.LocaleDisplay.display_name \"en-US-u-ca-gregory-cu-aud\"\n{:ok, \"American English (Gregorian Calendar, Currency: A$)\"}\n\niex> Cldr.LocaleDisplay.display_name \"en-US-u-ca-gregory-cu-aud\", locale: \"fr\"\n{:ok, \"anglais américain (calendrier grégorien, devise : A$)\"}\n\niex> Cldr.LocaleDisplay.display_name \"nl-BE\"\n{:ok, \"Flemish\"}\n\niex> Cldr.LocaleDisplay.display_name \"nl-BE\", compound_locale: false\n{:ok, \"Dutch (Belgium)\"}\n```\n\n#","ref":"readme.html#examples"},{"type":"extras","title":"Rendering a list of locales in their own languages - Cldr Locale Display","doc":"When presenting a list of locales to a user for selection it may be appropriate to present those display name in the language of the locale. The package [ex_cldr_html](https://hex.pm/packages/ex_cldr_html) includes a helper function for this but a simple approach is also possible.\n\nThe following snippet renders the list of known locales as display names in each locales own language. It uses a backend module configuration noted above.\n\n```elixir\niex> MyApp.Cldr.known_locale_names()\n.... |> Enum.map(&{&1, MyApp.Cldr.LocaleDisplay.display_name!(&1, locale: &1, prefer: :menu)})\n.... |> Enum.sort\n[\n  {\"ar\", \"العربية\"},\n  {\"de\", \"Deutsch\"},\n  {\"en\", \"English\"},\n  {\"fr\", \"français\"},\n  {\"fr-CH\", \"français suisse\"},\n  {\"th\", \"ไทย\"},\n  {\"zh-Hans\", \"简体中文\"},\n  {\"zh-Hant\", \"繁體中文\"}\n]\n\n# In some cases it is preferred to not use compound\n# locale names. Note the different rendering for the\n# locale fr-CH\niex> MyApp.Cldr.known_locale_names\n.... |> Enum.map(&{&1, MyApp.Cldr.LocaleDisplay.display_name!(&1, locale: &1, compound_locale: false, prefer: :menu)})\n.... |> Enum.sort\n[\n  {\"ar\", \"العربية\"},\n  {\"de\", \"Deutsch\"},\n  {\"en\", \"English\"},\n  {\"fr\", \"français\"},\n  {\"fr-CH\", \"français (Suisse)\"},\n  {\"th\", \"ไทย\"},\n  {\"zh-Hans\", \"简体中文（简体）\"},\n  {\"zh-Hant\", \"繁體中文（繁體）\"}\n]\n```","ref":"readme.html#rendering-a-list-of-locales-in-their-own-languages"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Cldr Locale Display v1.4.1 - Changelog","doc":"This is the changelog for Cldr Locale Display v1.4.1 released on January 2nd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_locale_display/tags)\n\n#","ref":"changelog.html#cldr-locale-display-v1-4-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `ex_doc` dependency configuration. Thanks to @szymon-jez for the PR.\n\n* Fix project links in `mix.exs`. Thanks to @szymon-jez and @petrus-jvrensburg for the PRs.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Locale Display v1.4.0 - Changelog","doc":"This is the changelog for Cldr Locale Display v1.4.0 released on April 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_locale_display/tags)\n\n#","ref":"changelog.html#cldr-locale-display-v1-4-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes an exception that was being raised with the formatting locale has no display name data. This is typically the `:und` locale. An error is returned instead.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Locale Display v1.3.1 - Changelog","doc":"This is the changelog for Cldr Locale Display v1.3.0 released on August 28th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_locale_display/tags)\n\n#","ref":"changelog.html#cldr-locale-display-v1-3-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix the typespecs and documentation `Cldr.LocaleDisplay.display_name/2` supports locale names as atoms, strings or language tags. Thanks to @japplegame for the PR. Closes #3.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Locale Display v1.3.0 - Changelog","doc":"This is the changelog for Cldr Locale Display v1.3.0 released on February 23rd, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_locale_display/tags)\n\n#","ref":"changelog.html#cldr-locale-display-v1-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [ex_cldr version 2.26.0](https://hex.pm/packages/ex_cldr/2.26.0) which uses atoms for locale names and rbnf locale names. This is consistent with out elements of `t:Cldr.LanguageTag` where atoms are used where the cardinality of the data is fixed and relatively small and strings where the data is free format.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Locale Display v1.2.0 - Changelog","doc":"This is the changelog for Cldr Locale Display v1.2.0 released on October 28th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_locale_display/tags)\n\n#","ref":"changelog.html#cldr-locale-display-v1-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated to `ex_cldr 2.24` which implements [CLDR 40](https://cldr.unicode.org/index/downloads/cldr-40) data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Locale Display v1.2.0-rc.0 - Changelog","doc":"This is the changelog for Cldr Locale Display v1.2.0-rc.0 released on October 20th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_locale_display/tags)\n\n#","ref":"changelog.html#cldr-locale-display-v1-2-0-rc-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated to `ex_cldr 2.24` which implements [CLDR 40](https://cldr.unicode.org/index/downloads/cldr-40) data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Locale Display v1.1.2 - Changelog","doc":"This is the changelog for Cldr Locale Display v1.1.2 released on July 3rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_locale_display/tags)\n\n#","ref":"changelog.html#cldr-locale-display-v1-1-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix bug where not all locales have display names for the key `t` or the type `h0`\n\n* Fix bug where the locale into which we are localising is valid but not configured","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Locale Display v1.1.1 - Changelog","doc":"This is the changelog for Cldr Locale Display v1.1.1 released on July 3rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_locale_display/tags)\n\n#","ref":"changelog.html#cldr-locale-display-v1-1-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Actual fixes for the issue when the compound name includes the script (like zh-Hant).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Locale Display v1.1.0 - Changelog","doc":"This is the changelog for Cldr Locale Display v1.1.0 released on July 3rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_locale_display/tags)\n\n#","ref":"changelog.html#cldr-locale-display-v1-1-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correct an issue when the compound name includes the script (like zh-Hant).\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `display_names/{1,2}` to backend modules.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Locale Display v1.0.0 - Changelog","doc":"This is the changelog for Cldr Locale Display v1.0.0 released on July 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_locale_display/tags)\n\n#","ref":"changelog.html#cldr-locale-display-v1-0-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"This is the first release of `ex_cldr_locale_display` which implements the [CLDR locale display name algorithm](https://unicode-org.github.io/cldr/ldml/tr35-general.html#locale_display_name_algorithm).","ref":"changelog.html#enhancements"},{"type":"extras","title":"LICENSE","doc":"","ref":"license.html"},{"type":"extras","title":"License - LICENSE","doc":"Copyright 2018 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html#license"}],"content_type":"text/markdown"}